Dissolved carbon dioxide within aquatic areas of Doñana Natural Area (2010-2011)
-------------------------

#### Authors:
Huertas, I. Emma ([ICMAN-CSIC](http://www.icman.csic.es/))

Morris, Edward P. ([ICMAN-CSIC](http://www.icman.csic.es/))

#### Keywords:	
"Donana Natural Area"; wetland; pond; lake; "carbon dioxide"; pH; "total alkalinity"; temperature; salinity, phosphate; "dissolved silica"; "wind velocity"; "flood area"

#### Issue Date:	
2013-05-31

#### Abstract:	
This data set includes recently published data used to calculate air-water carbon dioxide fluxes within aquatic areas of Doñana Natural Area, SW Spain (Long: -6.373, Lat: 36.932, Datum: WSG84) between March 2010 and 2011.

#### Description:  
This data set includes measurements of water samples collected from 11 water bodies (*n* = 6 to 12 per water body) between March 2010 and March 2011 within Doñana Natural Area. Geographic coordinates of sampling positions and a Google Earth `.kml` file are provided. 

Approximately every 30 days in situ water conductivity (converted to salinity), temperature and pH were measured using a multi-probe (YSI-6920V2, YSI Incorporated, Yellow Springs, Ohio, USA) and filtered water samples were collected for laboratory analysis of dissolved phosphate, silica (using a Skalar San^++ 215 Continuous Flow Analyzer) and total alkalinity (using a Metrohm 794 Titroprocessor following the method described by [Mintrop et al. (2000)][1]. Dissolved carbon dioxide partial pressure was calculated from pH and total alkalinity using co2sys.xls [(Pierrot et al., 2000)][2] with the dissociation constants for carbon and sulphate of [(Cai and Wang 1998)][3] and [(Dickson 1990)][4], respectively. 

Carbon dioxide partial pressure in air and daily-ensemble-averaged horizontal wind velocity at 10m above the land surface were provided by the [ICTS Doñana Scientific Reserve](http://icts.ebd.csic.es) (ICTS-2009-39) and are included to allow calculations of air-water fluxes.

Estimates of the areal extent of the water bodies derived via remote sensing (DEIMOS-1 and Landsat 5 TM sensors) within each wetland region of Donana Natural Area are included to allow up-scaling of fluxes to regional air-water C transport rates. A Google Earth `.kml` file delineating the wetland regions is provided and a Google Earth `.kmz` file showing an indication of the aggregate water coverage derived from the DEIMOS-1 sensor (8 images between Aug 2010 and Sept. 2011) is included to allow qualitative visualization of the areal extent and duration of water coverage.

The data is provided as `[space]` delimitated plain text files and Google Earth `.kml` and `.kmz` files within a compressed folder that also includes a single `README` file (in `markdown` format converted to `HTML` and `PDF`) containing a detailed description of the data structure.

The publication Contribution of Doñana Wetlands to carbon sequestration. Edward P. Morris, Susana Flecha, Jordi Figuerola, Eduardo Costas, Gabriel Navarro, Javier Ruiz, Pablo Rodriguez and Emma Huertas is currently in press in PLOS ONE to be published in 2013. This research was supported by projects P09–RNM–4744 and 049/2010 funded by the Regional Government of Andalucia and the Spanish Ministry for Agriculture, Food and Environment, respectively. Further analytical details, acknowledgements, air-water fluxes and transport rates can be found in the publication. This dataset is subject to a Creative Commons License Attribution-Noncommercial-ShareAlike 3.0 Unported.

### General Notes
The data are provided under a Creative Commons License Attribution-Noncommercial-ShareAlike 3.0. If you use the data, please cite the article: Contribution of Doñana Wetlands to carbon sequestration (2013) Edward P. Morris, Susana Flecha, Jordi Figuerola, Eduardo Costas, Gabriel Navarro, Javier Ruiz, Pablo Rodriguez and Emma Huertas. PLOS ONE.

This research was supported by the projects P09–RNM–4744 and 049/2010 funded by the Regional Government of Andalucia and the Spanish Ministry for Agriculture, Food and Environment, respectively. Meteorological data was provided by the ICTS Doñana Scientific Reserve (ICTS-2009-39), Spanish Ministry of Science and Innovation. DEIMOS Imaging and USGS/NASA supplied remote sensing images. Further acknowledgements can be found in the associated publication.

Data collection and analytical techniques are given in detail with the associated publication, here we only give a brief details and a guide to the contents of the data files.

Data files are in plain text format with `[space]` used as the delimiter and text enclosed in `""`. All data files have column titles as the first line. `NA` is used to represent no data.

Positions of sites are approximate, actual sampling positions varied throughout the year depending on the extent of the water body.

### Geographical coordinates of water sampling sites
[`Donana_water_sites_Geo_coordinates.txt`](data/Donana_water_sites_Geo_coordinates.txt) provides the geographical coordinates of the sites. `STATION` represents the approximate local name of the site. `ST.ID` represents the code (used to link to other data tables) for each site. `long` and `lat` are longitude and latitude, respectively. Geographic projection and WSG84 datum is used (EPSG:4326).

For convenience [`Donana_water_sites.kml`](data/Donana_water_sites.kml) is also included to allow visualization of the site positions in Google Earth (or other GIS software; note `kml` files have the Google Mercator projection [EPSG:900913]).   

### Water physiochemical properties
[`Donana_water_pCO2_data.txt`](data/Donana_water_pCO2_data.txt) provides data from approximately monthly water sampling data between March 2010 and March 2011. Temperature, salinity and pH were measured with a multi-probe (YSI-6920V2, YSI Incorporated, Yellow Springs, Ohio, USA). Total alkalinity, phosphate and dissolved silica were measured in the laboratory. pCO2 was calculated using pH and total alkalinity with `co2sys.xls` (ver.14).

`SAMP.EVENT` is a convenience code used to denominate each individual period. `time.stamp.gmt` is the date and time (GMT or UTC) at which the sample was collected, in extended ISO8601 format. `ST.ID` represents the code (used to link to other data tables) for each site. `T.degC` is the water temperature in degrees Celcius. `Salinity` is the water salinity (no units), calculated from conductivity. `TA.umolL` is total alkalinity with units micro mol per liter. `pH` is given using the National Bureau of Standards (NBS) scale at in situ temperature. `PO4.umolL` is dissolved inorganic phosphate concentration (i.e., not organic or total) with units micro mol per liter. `SiO3.umolL` is dissolved silica with units micro mol per liter. `pCO2.uatm` is calculated carbon dioxide partial pressure in the water with units micro atmospheres.

### Meteorological data
Meteorological data was provided by the ICTS Doñana Scientific Reserve (http://icts.ebd.csic.es), see the website for explicit details.

[`Donana_air_pCO2_data.txt`](data/Donana_air_pCO2_data.txt) contains daily averages of carbon dioxide partial pressure in the air from a single station. `STATION` represents the ICTS name of the station. `date` is the date representing the midpoint of the daily average in ISO8601 format. `pCO2air.uatm` carbon dioxide partial pressure in the air with units micro atmospheres.  

[`Donana_daily_mean_wind_u10_data.txt`](data/Donana_daily_mean_wind_u10_data.txt) contains spatially averaged daily-ensemble-averaged wind velocities at 10m (u10) above the land surface. `date` is the date representing the midpoint of the daily average in ISO8601 format. `u10.ms` is mean wind velocity at 10m above the land surface with units meters per second.

### Areal extent of water bodies
[`Donana_water_extent_by regions_km2_data.txt`](data/Donana_water_extent_by regions_km2_data.txt) provides information on the areal extent of the water bodies derived via remote sensing within each wetland region of Donana Natural Area. Note this table is in "long-table" format. `date` is the date representing the day of image acquisition in ISO8601 format. `Veta La Palma` contains the areal extent of the water bodies in kilometers squared for the region Veta La Palma.  `Donana wetlands` contains the areal extent of the water bodies in kilometers squared for the region Donana wetlands. `Dune ponds` contains the areal extent of the water bodies in kilometers squared for the region Dune ponds. `La Rocina` contains the areal extent of the water bodies in kilometers squared for the region Veta La Rocina. `satellite-sensor` is a code representing the sensor used to derive the water extent (`LS5TM` is Landsat 5 TM and `DEIMOS` is DEIMOS-1).

[`Donana_wetland_regions.kml`](data/Donana_wetland_regions.kml) is included to allow visualization of the delination of the wetland regions in Google Earth (or other GIS software; note the kml files have the Google Mercator [EPSG:900913] projection).

[`Donana_aggregate_water_coverage_DEIMOS_2010_2011.kmz`](data/Donana_aggregate_water_coverage_DEIMOS_2010_2011.kmz) is included to allow visualization of the areal extent and duration of the water bodies. Darker blues represent areas where water was present in more of the images examined. Note this image is just to give an indication for the study period and only including images collected on; "2010-08-30","2010-11-02","2010-12-16","2011-01-14","2011-02-02","2011-03-03","2011-04-16", "2011-09-13".  For detailed quantative multi-annual data on hydroperiods in Donana see the studies conducted by [LAST-EBD](http://www.ebd.csic.es/website1/Sede%20Central/LabSIG.aspx).

[1]: http://digital.csic.es/bitstream/10261/25136/1/48026102.pdf
[2]: http://dx.doi.org/10.3334/CDIAC/otg.CO2SYS_XLS_CDIAC105a
[3]: http://wcai.myweb.uga.edu/paper/CaiWang1998.pdf
[4]: http://www.sciencedirect.com/science/article/pii/002196149090074Z
